@@ -7,11 +7,11 @@ from kks.util.ejudge import EjudgeSession, save_auth_data
 @click.command(short_help='Authorize and save authentication data to configuration directory')
 @click.option('-l', '--login', prompt=True)
 @click.password_option('-p', '--password', confirmation_prompt=False)
-@click.option('-g', '--group-id', type=int,
-              help='''2020 group id (for example, 193)''')
+@click.option('-g', '--group-id',
+              help='''2021 group id (e.g. 204, 2010 or 'free' for 'вольнослушатели')''')
 @click.option('-c', '--contest-id', type=int,
               help='''Ejudge contest id.
-              For example, https://caos.ejudge.ru/ej/client?contest_id=133 has contest id 133''')
+              For example, https://caos.myltsev.ru/cgi-bin/new-client?contest_id=133 has contest id 133''')
 @click.option('--store-password/--no-store-password', default=True,
               help='''Toggle storing plaintext password in config for auto-login.
               If disabled, only session cookies will be stored.
@@ -26,7 +26,7 @@ def auth(login, password, group_id, contest_id, store_password):
     - data.json      - data parsed from ejudge (page urls, for example)"""
 
     if group_id is None and contest_id is None:
-        group_id = click.prompt("Group Id (e.g. 193)", type=int)
+        group_id = click.prompt("2021 group id (e.g. 204, 2010 or 'free' for 'вольнослушатели')")
 
     if group_id is not None and contest_id is not None:
         click.secho("Specify either contest id, or group id, not both", fg='red', err=True)
@@ -35,7 +35,7 @@ def auth(login, password, group_id, contest_id, store_password):
     if contest_id is None:
         contest_id = get_contest_id(group_id)
         if contest_id is None:
-            click.secho(f'Invalid group id "{group_id}" (should be between 191 and 1911)', fg='red', err=True)
+            click.secho(f"Invalid group id '{group_id}' (should be either a number from 201 to 2010 or 'free'", fg='red', err=True)
             return
 
     session = EjudgeSession(auth=False)
