@@ -1,8 +1,9 @@
-import subprocess
 import sys
 
 import click
 
+from kks.util.compat import subprocess
+
 
 @click.command()
 @click.argument('args', nargs=-1)
