@@ -13,15 +13,23 @@ from kks.errors import APIError
 from kks.util.h2t import HTML2Text
 
 
-CONTEST_ID_BY_GROUP = {
-    f'20{group}': int(f'20{group}')
-    for group in range(1, 11)
-}
+CONTEST_ID_BY_GROUP = {}
+CONTEST_ID_BY_GROUP.update({
+    f'19{group}': 130 + group for group in range(1, 12)
+})
+CONTEST_ID_BY_GROUP.update({
+    f'20{group}': int(f'20{group}') for group in range(1, 11)
+})
 CONTEST_ID_BY_GROUP['free'] = 2021
 
+GROUP_ID_BY_CONTEST = {
+    contest_id: group_id for group_id, contest_id in CONTEST_ID_BY_GROUP.items()
+}
+
 
 PROBLEM_INFO_VERSION = 3
-SERVER_TZ = timezone(timedelta(hours=3))  # MSK
+SERVER_TZ = timezone(timedelta(hours=0))  # UTC
+MSK_TZ = timezone(timedelta(hours=3))
 
 
 class Links:
@@ -126,11 +134,11 @@ class CacheKeys:
 class Submission:
     def __init__(self, row):
         cells = row.find_all('td')
-        self.id = int(cells[0].text)
+        self.id = int(cells[0].text.rstrip('#'))
         self.problem = cells[3].text
         self.compiler = cells[4].text
         self.status = cells[5].text
-        self.source = cells[8].find('a')['href'].replace('view-source', 'download-run')
+        self.source = cells[8].find('a')['href'].replace(f'action=36', f'action=91')
         report_link = cells[9].find('a')
         self.report = report_link['href'] if report_link is not None else None
 
@@ -289,7 +297,7 @@ class Deadlines:
     def parse(text):
         """Parse MSK datetime string (obtained from a problem page) and convert it to UTC"""
         dt = datetime.strptime(text, '%Y/%m/%d %H:%M:%S')
-        return dt.replace(tzinfo=SERVER_TZ)
+        return dt.replace(tzinfo=SERVER_TZ).astimezone(MSK_TZ)
 
 
 class ProblemInfo:
@@ -486,15 +494,12 @@ class FullProblem(SummaryProblem):
         return converter.handle(str(self._html))
 
 
-def get_contest_id(group_id):
+def get_contest_id(group_id: str) -> int:
     return CONTEST_ID_BY_GROUP.get(group_id, None)
 
 
-def get_group_id(contest_id):
-    for group, contest in CONTEST_ID_BY_GROUP.items():
-        if contest_id == contest:
-            return group
-    return None
+def get_group_id(contest_id: int) -> str:
+    return GROUP_ID_BY_CONTEST.get(contest_id, None)
 
 
 def get_contest_url(auth_data):
